class ProviderStatusesController < ApplicationController
  layout 'test' if MagicNumber['test_layout']
  before_filter :authenticate_admin!, :only => [:index, :show, :edit, :update, :destroy, :licenses_import, :artists_import, :original_pictures_import, :import]
  
  private
  
  def licenses_port
    licenses = export_by('licenses_export', @provider_status, params[:date])
    return nil unless licenses
    ProviderLicense.import @provider_status.provider.id, licenses
  end
  
  def artists_port
    artists = export_by('artists_export', @provider_status, params[:date])
    return nil unless artists
    ProviderArtist.import @provider_status.provider.id, artists
  end
  
  def original_pictures_port
    original_pictures = export_by('original_pictures_export', @provider_status, params[:date])
    return nil unless original_pictures
    pictures = export_by('pictures_export', @provider_status, params[:date])
    return nil unless pictures
    ProviderOriginalPicture.import @provider_status.provider.id, original_pictures, pictures
  end
  
  def port
    exports = export_by('export', @provider_status, params[:date])
    return nil unless exports
    ProviderStatus.import @provider_status.provider.id, exports
  end
  
  public
  
  def index
    @page = ProviderStatus.page params[:page]
    @page_size = ProviderStatus.page_size params[:page_size]
    @hide = params[:hide]
    @provider_statuses = if @hide.blank?
      ProviderStatus.list(@page, @page_size)
    else
      ProviderStatus.available_list(@page, @page_size)
    end

    respond_to do |format|
      format.html # index.html.erb
      format.json { render :json => @provider_statuses.to_json(ProviderStatus.list_json_opt) }
    end
  end

  def show
    @provider_status = ProviderStatus.show(params[:id], @admin)

    respond_to do |format|
      format.html # show.html.erb
      format.json { render :json => @provider_status.to_json(ProviderStatus.show_json_opt) }
    end
  end

  def edit
    @provider_status = ProviderStatus.edit(params[:id], @admin)
    respond_to do |format|
      format.html 
      format.js
    end
  end

  def update
    @provider_status = ProviderStatus.edit(params[:id], @admin)
    @provider_status.attributes = params[:provider_status]
    @provider_status.overwrite
    respond_to do |format|
      if @provider_status.save
        flash[:notice] = I18n.t('provider_statuses.flash.notice.created')
        format.html { redirect_to @provider_status }
        format.json { head :ok }
      else
        format.html { render action: "edit" }
        format.json { render json: @provider_status.errors, status: :unprocessable_entity }
      end
    end
  end

  def destroy
    @provider_status = ProviderStatus.edit(params[:id], @admin)
    respond_to do |format|
      if @provider_status.stop
        flash[:notice] = I18n.t('provider_statuses.flash.notice.stopped')
        format.html { redirect_to provider_statuses_url }
        format.json { head :ok }
      else
        flash[:notice] = I18n.t('provider_statuses.flash.notice.not_stopped')
        format.html { render action: "edit" }
        format.json { render json: @provider_status.errors, status: :unprocessable_entity }
      end
    end
  end
  
  def licenses_import
    @provider_status = ProviderStatus.show(params[:id], @admin)
    raise ActiveRecord::Forbidden if @provider_status.status == 0
    @failures = licenses_port
    respond_to do |format|
      format.html # show.html.erb
      format.json { render :json => @failures.to_json() }
    end
  end
  
  def artists_import
    @provider_status = ProviderStatus.show(params[:id], @admin)
    raise ActiveRecord::Forbidden if @provider_status.status == 0
    @failures = artists_port
    respond_to do |format|
      format.html # show.html.erb
      format.json { render :json => @failures.to_json() }
    end
  end
  
  def original_pictures_import
    @provider_status = ProviderStatus.show(params[:id], @admin)
    raise ActiveRecord::Forbidden if @provider_status.status == 0
    @failures = original_pictures_port
    respond_to do |format|
      format.html # show.html.erb
      format.json { render :json => @failures.to_json() }
    end
  end
  
  def import
    @provider_status = ProviderStatus.show(params[:id], @admin)
    raise ActiveRecord::Forbidden if @provider_status.status == 0
    @failures = port
    respond_to do |format|
      format.html # show.html.erb
      format.json { render :json => @failures.to_json() }
    end
  end
  
end
