class ProviderLicense < ActiveRecord::Base
  belongs_to :provider
  belongs_to :license, :foreign_key => :demanders_license_id
  
  validates :provider_id, :presence => true, :numericality => true, :existence => true
  validates :providers_license_id, :presence => true, :numericality => true
  validates :demanders_license_id, :presence => true, :numericality => true
  
  def self.get_one pid, plid
    ProviderLicense.find_by_provider_id_and_providers_license_id(pid, plid) || ProviderLicense.new
  end
  
  def self.exist_license pid, plid
    ProviderLicense.find_by_provider_id_and_providers_license_id(pid, plid) != nil
  end
  
  def self.import pid, providers_licenses
    res = []
    ProviderLicense.transaction do
      providers_licenses.each do |providers_license|
        if ProviderLicense.exist_license(pid, providers_license['id'])
        else
          if demander_license = License.find_by_name(providers_license['name'])
            pl = ProviderLicense.new :provider_id => pid, :providers_license_id => providers_license['id'], :demanders_license_id => demander_license.id
            unless pl.save
              res << providers_license
            end
          else
            res << providers_license
          end
        end
      end
      raise ActiveRecord::Rollback if res.any?
    end
    res
  end
  
end
